@@ -8,6 +8,12 @@ from pollination.honeybee_radiance.contrib import DaylightContribution
 @dataclass
 class DirectSunHoursCalculation(DAG):
 
+    timestep = Inputs.int(
+        description='Input wea timestep. This value will be used to divide the '
+        'cumulative results to ensure the units of the output are in hours.', default=1,
+        spec={'type': 'integer', 'minimum': 1, 'maximum': 60}
+    )
+
     sun_modifiers = Inputs.file(
         description='A file with sun modifiers.'
     )
@@ -34,11 +40,12 @@ class DirectSunHoursCalculation(DAG):
     )
 
     bsdfs = Inputs.folder(
-        description='Folder containing any BSDF files needed for ray tracing.'
+        description='Folder containing any BSDF files needed for ray tracing.',
+        optional=True
     )
 
-    @task(template=DaylightContribution, sub_folder='direct-radiation')
-    def direct_radiation_calculation(
+    @task(template=DaylightContribution, sub_folder='direct-irradiance')
+    def direct_irradiance_calculation(
         self,
         fixed_radiance_parameters='-aa 0.0 -I -faa -ab 0 -dc 1.0 -dt 0.0 -dj 0.0 -dr 0',
         conversion='0.265 0.670 0.065',
@@ -57,11 +64,11 @@ class DirectSunHoursCalculation(DAG):
         ]
 
     @task(
-        template=ConvertToBinary, needs=[direct_radiation_calculation],
+        template=ConvertToBinary, needs=[direct_irradiance_calculation],
         sub_folder='direct-sun-hours'
     )
     def convert_to_sun_hours(
-        self, input_mtx=direct_radiation_calculation._outputs.result_file,
+        self, input_mtx=direct_irradiance_calculation._outputs.result_file,
         grid_name=grid_name, minimum=0, include_min='exclude'
     ):
         return [
@@ -76,7 +83,8 @@ class DirectSunHoursCalculation(DAG):
         sub_folder='cumulative-sun-hours'
     )
     def calculate_cumulative_hours(
-        self, input_mtx=convert_to_sun_hours._outputs.output_mtx, grid_name=grid_name
+        self, input_mtx=convert_to_sun_hours._outputs.output_mtx,
+        grid_name=grid_name, divisor=timestep
     ):
         return [
             {
